@@ -1,6 +1,9 @@
 package Devel::Confess;
 use strict;
-use warnings;
+use warnings FATAL => 'all';
+
+our $VERSION = '0.002001';
+$VERSION = eval $VERSION;
 
 use Carp::Always::EvenObjects ();
 our @ISA = qw(Carp::Always::EvenObjects);
